@@ -42,9 +42,9 @@ package Algorithm::Evolutionary::Op::Uniform_Crossover;
 
 use lib qw(../../..);
 
-our ($VERSION) = ( '$Revision: 3.2 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 2.3 $ ' =~ /(\d+\.\d+)/ );
 
-use Clone qw(clone);
+use Clone::Fast qw(clone);
 use Carp;
 
 use base 'Algorithm::Evolutionary::Op::Base';
@@ -52,7 +52,6 @@ use base 'Algorithm::Evolutionary::Op::Base';
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::String';
 our $ARITY = 2;
-our %parameters = ( crossover_rate => 2 );
 
 =head2 new( [$options_hash] [, $operation_priority] )
 
@@ -66,23 +65,36 @@ of points, that is, the default would be
 sub new {
   my $class = shift;
   my $hash = { crossover_rate => shift || 0.5 };
-  croak "Crossover probability must be less than 1" 
-    if $hash->{'crossover_rate'} >= 1;
   my $priority = shift || 1;
   my $self = Algorithm::Evolutionary::Op::Base::new( $class, $priority, $hash );
   return $self;
 }
 
+=head2 create( [$crossover_rate] )
+
+Creates a new 1 or 2 point crossover operator. But this is just to
+have a non-empty chromosome. Defaults to 2 point
+
+=cut
+
+sub create {
+  my $class = shift;
+  my $self;
+  $self->{_crossover_rate} = shift || 0.5;
+  bless $self, $class;
+  return $self;
+}
+
 =head2 apply( $chromsosome_1, $chromosome_2 )
 
 Applies xover operator to a "Chromosome", a string, really. Can be
 applied only to I<victims> with the C<_str> instance variable; but
 it checks before application that both operands are of type
-L<String|Algorithm::Evolutionary::Individual::String>.
+L<BitString|Algorithm::Evolutionary::Individual::String>.
 
 Changes the first parent, and returns it. If you want to change both
 parents at the same time, check
-L<QuadXOver|Algorithm::Evolutionary::Op::QuadXOver> 
+L<QuadXOver|Algorithm::Evolutionary::Op:QuadXOver> 
 
 =cut
 
@@ -107,10 +119,10 @@ sub  apply ($$$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/02/14 06:55:36 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Uniform_Crossover.pm,v 3.2 2011/02/14 06:55:36 jmerelo Exp $ 
+  CVS Info: $Date: 2009/03/19 18:07:54 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Uniform_Crossover.pm,v 2.3 2009/03/19 18:07:54 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.2 $
+  $Revision: 2.3 $
   $Name $
 
 =cut
